<?php


function squirrelmail_plugin_init_sent_confirmation()
{

	global $squirrelmail_plugin_hooks;

        $squirrelmail_plugin_hooks['compose_send']['sent_confirmation']            = 'sent_conf_message_sent';
        $squirrelmail_plugin_hooks['generic_header']['sent_confirmation']          = 'sent_conf_check_is_sent';
        $squirrelmail_plugin_hooks['compose_bottom']['sent_confirmation']          = 'sent_conf_compose_bottom';


        $squirrelmail_plugin_hooks['options_display_inside']['sent_confirmation']  = 'sent_conf_show_options';
        $squirrelmail_plugin_hooks['options_display_save']['sent_confirmation']    = 'sent_conf_save_options';


}



//
//
function sent_confirmation_version() {

   return '1.2';

}



// This is the text that appears on the option page
//
function sent_conf_show_options() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_options();

}



// Here we save the user's sent_confirmation preferences
//
function sent_conf_save_options() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_options_save();

}



// set flag indicating message was sent
function sent_conf_message_sent() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_message_sent_do();

}



// 
//
function sent_conf_check_is_sent() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_check_is_sent_do();

}



// 
//
function sent_conf_compose_bottom() {

    if (defined('SM_PATH'))
       include_once(SM_PATH . 'plugins/sent_confirmation/functions.php');
    else
       include_once('../plugins/sent_confirmation/functions.php');

    sent_conf_compose_bottom_do();

}


?>
